@@ -7,7 +7,7 @@
 
 """Provides QtQml classes and functions."""
 
-from . import PYQT5, PYQT6, PYSIDE2, PYSIDE6, QtBindingsNotFoundError
+from . import PYQT5, PYQT6, PYSIDE2, PYSIDE6
 
 if PYQT5:
     from PyQt5.QtQml import *
@@ -17,5 +17,3 @@ elif PYSIDE6:
     from PySide6.QtQml import *
 elif PYSIDE2:
     from PySide2.QtQml import *
-else:
-    raise QtBindingsNotFoundError()
